@@ -1,12 +1,12 @@
-# $Id: param.rb,v 1.109 2010/06/21 11:27:38 chabannf Exp $
+# $Id: param.rb,v 1.110 2010/10/04 09:29:50 rpaulmier Exp $
 
 # 
 # CONTACT     : zonecheck@nic.fr
 # AUTHOR      : Stephane D'Alu <sdalu@nic.fr>
 #
 # CREATED     : 2002/08/02 13:58:17
-# REVISION    : $Revision: 1.109 $ 
-# DATE        : $Date: 2010/06/21 11:27:38 $
+# REVISION    : $Revision: 1.110 $ 
+# DATE        : $Date: 2010/10/04 09:29:50 $
 #
 # CONTRIBUTORS: (see also CREDITS file)
 #
@@ -216,7 +216,9 @@ module ZoneCheck
              ips_str =~ Dnsruby::IPv6::Regex
             raise ParamError, $mc.get("param:ns_ip") % ips_str
           end
-          
+
+          # Canonicalize host names (final dot mandatory)
+          host_str = host_str + '.' unless host_str =~ /.\.$/          
           host = Dnsruby::Name::create(host_str)
           ips_str.split(/\s*,\s*|\s+/).each { |str|
             if str =~ Dnsruby::IPv4::Regex
@@ -235,6 +237,8 @@ module ZoneCheck
                !(entry =~ /^[A-Za-z0-9.-]+$/)
               raise ParamError, $mc.get("param:ns_name") % entry
             end
+            # Canonicalize host names (final dot mandatory)
+            entry = entry + '.' unless entry =~ /.\.$/
             host = Dnsruby::Name::create(entry)
           end
           @ns_input << [ host, ips ]
